﻿using NFC;
using NFC.Interfaces;
using System;
using System.Collections.Generic;
using System.Text;

namespace Borepin.Service.NFC
{
    /// <summary>
    /// Service to provide hardware specific NFC Interfaces
    /// </summary>
    public interface INFCService
    {
        /// <summary>
        /// Indicates if NFC Hardware is available
        /// </summary>
        bool IsAvailable { get; }

        /// <summary>
        /// Indicates if NFC Hardware is enabled
        /// </summary>
        bool IsEnabled { get; }

        /// <summary>
        /// Indicates if NFC Card is connected
        /// </summary>
        bool IsConnected { get; }

        /// <summary>
        /// Get a list of availible NFC ReaderIDs
        /// </summary>
        IList<string> GetReaderIDs();

        /// <summary>
        /// Connect with ReaderID to NFC Card
        /// </summary>
        /// <param name="readerID">ReaderID from GetReaderIDs</param>
        void Connect(string readerID);

        /// <summary>
        /// Disconnects Reader from NFC Card
        /// </summary>
        void Disconnect();

        /// <summary>
        /// Transmit APDUCommand to Card if connected
        /// </summary>
        APDUResponse Transmit(APDUCommand command);
    }
}
